@@ -1,13 +1,13 @@
 package Complete::Host;
 
-our $DATE = '2015-09-16'; # DATE
-our $VERSION = '0.00'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.01'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use Complete::Setting;
+use Complete::Common;
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -20,6 +20,11 @@ our %SPEC;
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'Completion routines related to hostnames',
+    description => <<'_',
+
+This includes grabbing hostnames from /etc/hosts, ~/ssh/.known_hosts, etc.
+
+_
 };
 
 1;
@@ -37,12 +42,15 @@ Complete::Host - Completion routines related to hostnames
 
 =head1 VERSION
 
-This document describes version 0.00 of Complete::Host (from Perl distribution Complete-Host), released on 2015-09-16.
+This document describes version 0.01 of Complete::Host (from Perl distribution Complete-Host), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
 B<NAME GRAB. NOT YET IMPLEMENTED.>
 
+
+This includes grabbing hostnames from /etc/hosts, ~/ssh/.known_hosts, etc.
+
 =for Pod::Coverage .+
 
 =head1 SEE ALSO
